pub struct SimpleCaptureDevice<Q: VirtioMediaEventQueue, HM: VirtioMediaHostMemoryMapper> { /* private fields */ }Expand description
A simplistic video capture device, used to demonstrate how device code can be written, or for testing VMMs and guests without dedicated hardware support.
This device supports a single pixel format (RGB3) and a single resolution, and generates
frames of varying uniform color. The only buffer type supported is MMAP
Implementations
Sourceimpl<Q, HM> SimpleCaptureDevice<Q, HM>where
Q: VirtioMediaEventQueue,
HM: VirtioMediaHostMemoryMapper,
impl<Q, HM> SimpleCaptureDevice<Q, HM>where
Q: VirtioMediaEventQueue,
HM: VirtioMediaHostMemoryMapper,