VideoDecoderBackendEvent

Enum VideoDecoderBackendEvent 

pub enum VideoDecoderBackendEvent {
    StreamFormatChanged,
    InputBufferDone {
        buffer_id: u32,
        error: i32,
    },
    FrameCompleted {
        buffer_id: u32,
        timestamp: timeval,
        bytes_used: Vec<u32>,
        is_last: bool,
    },
}
Events reported by the VideoDecoderBackendSession::next_event method.

Variants



StreamFormatChanged

Sent whenever the format of the stream has changed. The new format can be read using VideoDecoderBackendSession::current_format.



InputBufferDone

Sent whenever an OUTPUT buffer is done processing and can be reused.

Fields

buffer_id: u32
error: i32

If error != 0, indicate the error flag on the corresponding v4l2_buffer



FrameCompleted

Sent whenever a decoded frame is ready on the CAPTURE queue.

Fields

buffer_id: u32
timestamp: timeval
bytes_used: Vec<u32>
is_last: bool