pub struct LeWrapper<T: VmediaType>(/* private fields */);Expand description
Private wrapper for all types that can be sent/received over virtio. Wrapped objects are guaranteed to use little-endian representation.
Wrapped objects are inaccessible and can only be passed to methods writing to virtio
descriptors. Self::into_native can be used to retrieve the object in its native ordering.
Implementations
Sourceimpl<T: VmediaType> LeWrapper<T>
impl<T: VmediaType> LeWrapper<T>
Sourcepub fn into_native(self) -> T
pub fn into_native(self) -> T
Convert the wrapped object back to native ordering and return it.