SimpleCaptureDevice

Struct SimpleCaptureDevice 

pub struct SimpleCaptureDevice<Q: VirtioMediaEventQueue, HM: VirtioMediaHostMemoryMapper> { /* private fields */ }
A simplistic video capture device, used to demonstrate how device code can be written, or for testing VMMs and guests without dedicated hardware support.

This device supports a single pixel format (RGB3) and a single resolution, and generates frames of varying uniform color. The only buffer type supported is MMAP

Implementations

Source

impl<Q, HM> SimpleCaptureDevice<Q, HM>

pub fn new(evt_queue: Q, mapper: HM) -> Self